import os
import requests

from .fs import *
# from .fs import cwd
# from .fs import write
# 数据转化
from .to import *
from .desco import *
# from .desco import try_error
# from .desco import calc


# 操作系统指令
# from ..cmd_exe import run


def test():
    print("test            :", 15160)
